@@ -104,8 +104,9 @@ class accuinsight(Common):
             return None
 
     class add_experiment(object):
-        def __init__(self, model_name, *args, model_monitor=False):
+        def __init__(self, model_name, *args, model_monitor=False, runtime=False):
             self.shap_on = model_monitor
+            self.runtime = runtime
             logging.info('Using add_experiment(model_monitor={})'.format(model_monitor))
 
             if type(model_name) == pipeline.Pipeline:
@@ -312,6 +313,8 @@ class accuinsight(Common):
                                             env_value[LcConst.BACK_END_API_PORT],
                                             env_value[LcConst.BACK_END_API_URI])
             modeler_rest.lc_create_run(run_meta)
+            if self.runtime:
+                accuinsight.set_runtime_model('sklearn')
 
         def log_params(self, param=None):
             # sklearn/xgboost/lightgbm
