@@ -80,15 +80,12 @@ class AddDeployLog:
             self.deploy_alarm.notifiers['mail'] = address
 
     def add_log(self, messages):
-        if not self.swagger:
-            if messages:
-                self.deploy_alarm.type = "DeployAPI"
+        if not self.swagger and messages:
+            self.deploy_alarm.type = "DeployAPI"
 
-                for message in messages:
-                    self.deploy_alarm.message = message
-                    self.deploy_log_api.call_rest_api('POST', self.deploy_alarm.get_alarm_param(), "alarm")
-
-            # self.deploy_log_api.call_rest_api('POST', self.deploy_log.get_logging_param())
+            for message in messages:
+                self.deploy_alarm.message = message
+                self.deploy_log_api.call_rest_api('POST', self.deploy_alarm.get_alarm_param(), "alarm")
 
     def get_log_info(self):
         try:
