@@ -1,7 +1,6 @@
 from collections.abc import Mapping
 from csv import DictReader
 import json
-from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_current_run
 from Accuinsight.modeler.core.LcConst.LcConst import RUN_RESULT_PATH, RUN_MODEL_VISUAL_CSV_PATH, \
     RUN_MODEL_VISUAL_JSON_PATH, RUN_MODEL_JSON_PATH, SELECTED_METRICS
 from Accuinsight.modeler.protos.life_cycle_pb2 import LcMetric, LcParam
@@ -11,14 +10,6 @@ from Accuinsight.modeler.core.Run.ParseRun import Parse_Helper
 # get metric path with run type
 
 
-def _get_current_run():
-    # {'run_name': 'keras',
-    #  'json_path': 'model-info-json/keras_nn-1.json',
-    #  'csv_path': 'for-visual-csv/keras_nn-history-1.csv'}
-
-    return get_current_run()
-
-
 def load_parameter(run_meta):
     run_result_path = run_meta[RUN_RESULT_PATH]
     json_path = run_result_path[RUN_MODEL_JSON_PATH]
@@ -228,8 +219,7 @@ def parse_parameter(run_meta):
     return _parse_optimizer_info(param_data)
 
 
-def parse_run_result():
-    run_info_json = _get_current_run()
+def parse_run_result(run_info_json):
     result_dict = {'metrics': None, 'params': None, 'visual': None}
 
     metric_data = parse_metric(run_meta=run_info_json)
