@@ -40,12 +40,7 @@ def set_current_runs(run_name):
     return _runData
 
 
-def get_current_run():
-    with open(LcConst.ENV_JUPYTER_HOME_DIR + LcConst.RUN_ROOT_PATH + 'run_info.json') as json_file:
-        return json.load(json_file)
-
-
-def _get_run_data_value_by_key():
+def clear_runs(start_time, end_time, delta_time):
     global _runData
     run_obj = _runData[0]
     run_meta = OrderedDict()
@@ -53,12 +48,6 @@ def _get_run_data_value_by_key():
     for key in run_obj.__dict__.keys():
         run_meta[key] = run_obj[key]
 
-    return run_meta
-
-
-def clear_runs(start_time, end_time, delta_time, json_path=None):
-    global _runData
-    run_meta = _get_run_data_value_by_key()
     run_meta[LcConst.START_TIME] = start_time
     run_meta[LcConst.END_TIME] = end_time
     run_meta[LcConst.DELTA_TIME] = delta_time
@@ -109,6 +98,8 @@ def clear_runs(start_time, end_time, delta_time, json_path=None):
 
     _runData.pop()
 
+    return run_meta
+
 
 def _set_result_full_path(dict_path):
     global _runData
@@ -250,8 +241,7 @@ def dict_to_list(dict_data):
     return ["{}=={}".format(key, dict_data[key] or "<unknown>") for key in dict_data.keys()]
 
 
-def print_run_info():
-    run_obj = get_current_run()
+def print_run_info(run_obj):
 
     # DL & Classification
     if 'keras' in run_obj[LcConst.RUN_OBJ_NAME]:
