@@ -54,7 +54,10 @@ def y_pred_reshape(model, X_test):
     prob = model.predict(X_test)
 
     if prob.ndim == 1:
-        y_pred = [1 if i >= 0.5 else 0 for i in prob]
+        try:
+            y_pred = [1 if i >= 0.5 else 0 for i in prob]
+        except TypeError:
+            y_pred = list(prob)
 
     elif prob.ndim == 2:
         if prob.shape[1] == 1:
